Rmdawn command-line interface (CLI) — Rmdawn 0.0.1 documentation

# Rmdawn command-line interface (CLI)

## rmdawn

Create an R markdown file from markdown and code files.

param in_files

  The list of the input files.

param out_file

  The name of the output R markdown file.

    rmdawn [OPTIONS] IN_FILES...

Options

`-o````,` `--out_file``<out>`

Arguments

`IN_FILES```

  Required argument(s)

## rmdusk

Extract YAML, markdown, and code files from a R markdown file.

param in_file

  The name of the input R markdown file.

    rmdusk [OPTIONS] IN_FILE

Arguments

`IN_FILE```

  Required argument

## rmdtor

Convert an R markdown file into an R script.

param in_file

  The name of the input R markdown file.

param out_file

  The name of the output R script.

    rmdtor [OPTIONS] IN_FILE

Options

`-o````,` `--out_file``<out_file>`

Arguments

`IN_FILE```

  Required argument

## rtormd

Convert an R markdown file into an R script.

param in_file

  The name of the input R markdown file.

param out_file

  The name of the output R script.

    rtormd [OPTIONS] IN_FILE

Options

`-o````,` `--out_file``<out>`

Arguments

`IN_FILE```

  Required argument

## render

Convert an R markdown file into an R script.

param in_file

  The name of the input R markdown file.

param out_file

  The name of the output R script.

param out_format

  The format of the output file.

    render [OPTIONS] IN_FILE

Options

`-o````,` `--out_file``<out_file>`

`-f````,` `--format``<out_format>`

Arguments

`IN_FILE```

  Required argument

## catren

Convert an R markdown file into an R script.

param in_files

  A list of YAML, markdown, and code file names.

param rmd_file

  The name of the intermediate rmd file.

param out_file

  The name of the final output file.

param out_format

  The format of the final output file.

    catren [OPTIONS] IN_FILES...

Options

`-r````,` `--rmd_file``<rmd_file>`

`-o````,` `--out_file``<out_file>`

`-f````,` `--format``<out_format>`

Arguments

`IN_FILES```

  Required argument(s)